@@ -1,6 +1,6 @@
 package Elastic::Model::TypeMap::ES;
 {
-  $Elastic::Model::TypeMap::ES::VERSION = '0.08';
+  $Elastic::Model::TypeMap::ES::VERSION = '0.09';
 }
 
 use strict;
@@ -33,7 +33,6 @@ has_type 'Elastic::Model::Types::UID',
             index                        => 'not_analyzed',
             omit_norms                   => 1,
             omit_term_freq_and_positions => 1,
-            index_name                   => "uid.${_}",
             }
     } qw(index type id routing);
 
@@ -44,7 +43,7 @@ has_type 'Elastic::Model::Types::UID',
         type       => 'object',
         dynamic    => 'strict',
         properties => \%props,
-        path       => 'just_name'
+        path       => 'full'
     );
 
     };
@@ -114,7 +113,7 @@ Elastic::Model::TypeMap::ES - Type maps for ElasticSearch-specific types
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 DESCRIPTION
 
@@ -147,26 +146,23 @@ via L<Elastic::Model::UID/"new_from_store()">. It is mapped as:
     {
         type        => 'object',
         dynamic     => 'strict',
-        path        => 'just_name',
+        path        => 'path',
         properties  => {
             index   => {
                 type                         => 'string',
                 index                        => 'not_analyzed',
-                index_name                   => 'uid.index',
                 omit_norms                   => 1,
                 omit_term_freq_and_positions => 1,
             },
             type => {
                 type                         => 'string',
                 index                        => 'not_analyzed',
-                index_name                   => 'uid.type',
                 omit_norms                   => 1,
                 omit_term_freq_and_positions => 1,
             },
             id   => {
                 type                         => 'string',
                 index                        => 'not_analyzed',
-                index_name                   => 'uid.id',
                 omit_norms                   => 1,
                 omit_term_freq_and_positions => 1,
             },
